# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.v1.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    date,
    datetime,
    file_type,
    none_type,
)


def lazy_import():
    from datadog_api_client.v1.model.group_widget_definition_type import GroupWidgetDefinitionType
    from datadog_api_client.v1.model.widget import Widget
    from datadog_api_client.v1.model.widget_layout_type import WidgetLayoutType
    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign

    globals()["GroupWidgetDefinitionType"] = GroupWidgetDefinitionType
    globals()["Widget"] = Widget
    globals()["WidgetLayoutType"] = WidgetLayoutType
    globals()["WidgetTextAlign"] = WidgetTextAlign


class GroupWidgetDefinition(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the name of the attribute. The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.

      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      validations (dict): The key is the name of the attribute. The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.

    """

    validations = {}

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            "background_color": (str,),
            "banner_img": (str,),
            "layout_type": (WidgetLayoutType,),
            "show_title": (bool,),
            "title": (str,),
            "title_align": (WidgetTextAlign,),
            "type": (GroupWidgetDefinitionType,),
            "widgets": ([Widget],),
        }

    attribute_map = {
        "layout_type": "layout_type",
        "type": "type",
        "widgets": "widgets",
        "background_color": "background_color",
        "banner_img": "banner_img",
        "show_title": "show_title",
        "title": "title",
        "title_align": "title_align",
    }

    read_only_vars = {}

    def __init__(self, layout_type, type, widgets, *args, **kwargs):
        """GroupWidgetDefinition - a model defined in OpenAPI

        Args:
            layout_type (WidgetLayoutType):
            type (GroupWidgetDefinitionType):
            widgets ([Widget]): List of widget groups.

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            background_color (str): Background color of the group title.. [optional]
            banner_img (str): URL of image to display as a banner for the group.. [optional]
            show_title (bool): Whether to show the title or not.. [optional] if omitted the server will use the default value of True
            title (str): Title of the widget.. [optional]
            title_align (WidgetTextAlign): [optional]
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

        self.layout_type = layout_type
        self.type = type
        self.widgets = widgets

    @classmethod
    def _from_openapi_data(cls, layout_type, type, widgets, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(GroupWidgetDefinition, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        self.layout_type = layout_type
        self.type = type
        self.widgets = widgets
        return self
