# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.v1.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    date,
    datetime,
    file_type,
    none_type,
)


def lazy_import():
    from datadog_api_client.v1.model.synthetics_browser_error import SyntheticsBrowserError
    from datadog_api_client.v1.model.synthetics_check_type import SyntheticsCheckType
    from datadog_api_client.v1.model.synthetics_core_web_vitals import SyntheticsCoreWebVitals
    from datadog_api_client.v1.model.synthetics_playing_tab import SyntheticsPlayingTab
    from datadog_api_client.v1.model.synthetics_step_detail_warning import SyntheticsStepDetailWarning
    from datadog_api_client.v1.model.synthetics_step_type import SyntheticsStepType

    globals()["SyntheticsBrowserError"] = SyntheticsBrowserError
    globals()["SyntheticsCheckType"] = SyntheticsCheckType
    globals()["SyntheticsCoreWebVitals"] = SyntheticsCoreWebVitals
    globals()["SyntheticsPlayingTab"] = SyntheticsPlayingTab
    globals()["SyntheticsStepDetailWarning"] = SyntheticsStepDetailWarning
    globals()["SyntheticsStepType"] = SyntheticsStepType


class SyntheticsStepDetail(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the name of the attribute. The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.

      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      validations (dict): The key is the name of the attribute. The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.

    """

    validations = {}

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            "browser_errors": ([SyntheticsBrowserError],),
            "check_type": (SyntheticsCheckType,),
            "description": (str,),
            "duration": (float,),
            "error": (str,),
            "playing_tab": (SyntheticsPlayingTab,),
            "screenshot_bucket_key": (bool,),
            "skipped": (bool,),
            "snapshot_bucket_key": (bool,),
            "step_id": (int,),
            "sub_test_step_details": ([SyntheticsStepDetail],),
            "time_to_interactive": (float,),
            "type": (SyntheticsStepType,),
            "url": (str,),
            "value": (
                bool,
                date,
                datetime,
                dict,
                float,
                int,
                list,
                str,
                none_type,
            ),
            "vitals_metrics": ([SyntheticsCoreWebVitals],),
            "warnings": ([SyntheticsStepDetailWarning],),
        }

    attribute_map = {
        "browser_errors": "browserErrors",
        "check_type": "checkType",
        "description": "description",
        "duration": "duration",
        "error": "error",
        "playing_tab": "playingTab",
        "screenshot_bucket_key": "screenshotBucketKey",
        "skipped": "skipped",
        "snapshot_bucket_key": "snapshotBucketKey",
        "step_id": "stepId",
        "sub_test_step_details": "subTestStepDetails",
        "time_to_interactive": "timeToInteractive",
        "type": "type",
        "url": "url",
        "value": "value",
        "vitals_metrics": "vitalsMetrics",
        "warnings": "warnings",
    }

    read_only_vars = {}

    def __init__(self, *args, **kwargs):
        """SyntheticsStepDetail - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            browser_errors ([SyntheticsBrowserError]): Array of errors collected for a browser test.. [optional]
            check_type (SyntheticsCheckType): [optional]
            description (str): Description of the test.. [optional]
            duration (float): Total duration in millisecond of the test.. [optional]
            error (str): Error returned by the test.. [optional]
            playing_tab (SyntheticsPlayingTab): [optional]
            screenshot_bucket_key (bool): Whether or not screenshots where collected by the test.. [optional]
            skipped (bool): Whether or not to skip this step.. [optional]
            snapshot_bucket_key (bool): Whether or not snapshots where collected by the test.. [optional]
            step_id (int): The step ID.. [optional]
            sub_test_step_details ([SyntheticsStepDetail]): If this steps include a sub-test. [Subtests documentation](https://docs.datadoghq.com/synthetics/browser_tests/advanced_options/#subtests).. [optional]
            time_to_interactive (float): Time before starting the step.. [optional]
            type (SyntheticsStepType): [optional]
            url (str): URL to perform the step against.. [optional]
            value (bool, date, datetime, dict, float, int, list, str, none_type): Value for the step.. [optional]
            vitals_metrics ([SyntheticsCoreWebVitals]): Array of Core Web Vitals metrics for the step.. [optional]
            warnings ([SyntheticsStepDetailWarning]): Warning collected that didn't failed the step.. [optional]
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(SyntheticsStepDetail, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        return self
