# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.v1.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    date,
    datetime,
    file_type,
    none_type,
)


def lazy_import():
    from datadog_api_client.v1.model.tree_map_color_by import TreeMapColorBy
    from datadog_api_client.v1.model.tree_map_group_by import TreeMapGroupBy
    from datadog_api_client.v1.model.tree_map_size_by import TreeMapSizeBy
    from datadog_api_client.v1.model.tree_map_widget_definition_type import TreeMapWidgetDefinitionType
    from datadog_api_client.v1.model.tree_map_widget_request import TreeMapWidgetRequest

    globals()["TreeMapColorBy"] = TreeMapColorBy
    globals()["TreeMapGroupBy"] = TreeMapGroupBy
    globals()["TreeMapSizeBy"] = TreeMapSizeBy
    globals()["TreeMapWidgetDefinitionType"] = TreeMapWidgetDefinitionType
    globals()["TreeMapWidgetRequest"] = TreeMapWidgetRequest


class TreeMapWidgetDefinition(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the name of the attribute. The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.

      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      validations (dict): The key is the name of the attribute. The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.

    """

    validations = {
        "requests": {
            "max_items": 1,
            "min_items": 1,
        },
    }

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            "color_by": (TreeMapColorBy,),
            "group_by": (TreeMapGroupBy,),
            "requests": ([TreeMapWidgetRequest],),
            "size_by": (TreeMapSizeBy,),
            "title": (str,),
            "type": (TreeMapWidgetDefinitionType,),
        }

    attribute_map = {
        "color_by": "color_by",
        "group_by": "group_by",
        "requests": "requests",
        "size_by": "size_by",
        "type": "type",
        "title": "title",
    }

    read_only_vars = {}

    def __init__(self, color_by, group_by, requests, size_by, type, *args, **kwargs):
        """TreeMapWidgetDefinition - a model defined in OpenAPI

        Args:
            color_by (TreeMapColorBy):
            group_by (TreeMapGroupBy):
            requests ([TreeMapWidgetRequest]): List of top list widget requests.
            size_by (TreeMapSizeBy):
            type (TreeMapWidgetDefinitionType):

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            title (str): Title of your widget.. [optional]
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

        self.color_by = color_by
        self.group_by = group_by
        self.requests = requests
        self.size_by = size_by
        self.type = type

    @classmethod
    def _from_openapi_data(cls, color_by, group_by, requests, size_by, type, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(TreeMapWidgetDefinition, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        self.color_by = color_by
        self.group_by = group_by
        self.requests = requests
        self.size_by = size_by
        self.type = type
        return self
